@@ -2,6 +2,9 @@
 Vue.component('edit-field', {
     template: '#edit-field',
     props: {
+        name: {
+            required: true
+        },
         value: {
             required: true
         },
@@ -515,7 +518,8 @@ var app = new Vue({
                     url: url,
                     method: 'PUT',
                     data: value,
-                    dataType: "json"
+                    dataType: "json",
+                    contentType: "application/json"
                 }
             ).done(
                 function ( data, status, jqXHR ) {
@@ -548,38 +552,15 @@ var app = new Vue({
                     url: url,
                     method: 'POST',
                     data: value,
-                    dataType: "json"
+                    dataType: "json",
+                    contentType: "application/json"
                 }
             ).done(
                 function ( data, status, jqXHR ) {
-                    var id = self.currentOperations['add'].schema['x-id-field'] || 'id';
-                    var urlParams = {};
-                    urlParams[ id ] = data;
-
-                    $.ajax(
-                        {
-                            url: self.fillUrl( self.currentOperations['get'].url, urlParams ),
-                            method: 'GET',
-                            dataType: 'json'
-                        }
-                    ).done(
-                        function ( data, status, jqXHR ) {
-                            self.items.unshift( data );
-                            self.total++;
-                            self.cancelAddItem();
-                            self.addToast( { icon: "fa-save", title: "Added", text: "Item added" } );
-                        }
-                    ).fail(
-                        function ( jqXHR, textStatus, errorThrown ) {
-                            if ( jqXHR.responseJSON ) {
-                                self.parseErrorResponse( jqXHR.responseJSON );
-                                self.$set( self.error, 'addItem', 'Could not fetch new item' );
-                            }
-                            else {
-                                self.$set( self.error, 'addItem', jqXHR.responseText );
-                            }
-                        }
-                    );
+                    self.items.unshift( data );
+                    self.total++;
+                    self.cancelAddItem();
+                    self.addToast( { icon: "fa-save", title: "Added", text: "Item added" } );
                 }
             ).fail(
                 function ( jqXHR, textStatus, errorThrown ) {
@@ -623,13 +604,6 @@ var app = new Vue({
                             = marked( copy[k], { sanitize: false });
                     }
                 }
-                else if ( copy[k] === null ) {
-                    // `null` doesn't pass type checks, and Perl doesn't
-                    // distinguish between `undef` and `defined but no
-                    // value` in an object, so make this field `undef`
-                    // to Perl
-                    delete copy[k];
-                }
             }
             return JSON.stringify( copy );
         },
